@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3 date 2006-01-29
+ * version 0.4.0 date 2006-04-13
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -7,6 +7,7 @@
 
 #include "code.h"
 #include "config.h"
+#include "debug.h"
 #include "eeprom.h"
 #include "macros.h"
 #include "output.h"
@@ -51,7 +52,12 @@ static inline unsigned char CodeSetMac( unsigned char * pCode, unsigned char Cod
 
   //invalid length
   if( CodeLen != 8 )
+  {
+    debug_code_printf( "unknown" );
     return 0xFF;
+  }
+
+  debug_code_printf( "mac" );
 
   //get last 2 bytes from code
   b4 = Code3Bcd2Byte( pCode, 2 );
@@ -82,7 +88,12 @@ static inline unsigned char CodeSetIp( unsigned char * pCode, unsigned char Code
 
   //invalid length
   if( CodeLen != 14 )
+  {
+    debug_code_printf( "unknown" );
     return 0xFF;
+  }
+
+  debug_code_printf( "ip" );
 
   //get 4 bytes from code
   b0 = Code3Bcd2Byte( pCode, 2 );
@@ -111,7 +122,12 @@ static inline unsigned char CodeSetMask( unsigned char * pCode, unsigned char Co
 
   //invalid length
   if( CodeLen != 14 )
+  {
+    debug_code_printf( "unknown" );
     return 0xFF;
+  }
+
+  debug_code_printf( "subnet mask" );
 
   //get 4 bytes from code
   b[0] = Code3Bcd2Byte( pCode, 2 );
@@ -146,7 +162,12 @@ static inline unsigned char CodeSetGw( unsigned char * pCode, unsigned char Code
 
   //invalid length
   if( CodeLen != 14 )
+  {
+    debug_code_printf( "unknown" );
     return 0xFF;
+  }
+
+  debug_code_printf( "gateway ip" );
 
   //get 4 bytes from code
   b0 = Code3Bcd2Byte( pCode, 2 );
@@ -174,8 +195,13 @@ static inline unsigned char CodeSetS8pPort( unsigned char * pCode, unsigned char
 
   //invalid length
   if( CodeLen != 7 )
+  {
+    debug_code_printf( "unknown" );
     return 0xFF;
+  }
   
+  debug_code_printf( "s8p port" );
+
   //get port number from from code
   port = Code5Bcd2Word( pCode, 2 );
 
@@ -196,7 +222,12 @@ static inline unsigned char CodeSetS8pKey( unsigned char * pCode, unsigned char
 
   //invalid length
   if( CodeLen != 2 + count( key ) * 3 )
+  {
+    debug_code_printf( "unknown" );
     return 0xFF;
+  }
+
+  debug_code_printf( "s8p key" );
 
   //get bytes from code
   for( i = 0, j = 2; i < count( key ); i++, j += 3 )
@@ -214,21 +245,26 @@ static inline unsigned char CodeSetS8pKey( unsigned char * pCode, unsigned char
 //set port for webserver
 //code is stored in BCD, MSB first - magic is already removed
 //returns 0x00 on success
-static inline unsigned char CodeSetWebPort( unsigned char * pCode, unsigned char CodeLen )
+static inline unsigned char CodeSetHttpPort( unsigned char * pCode, unsigned char CodeLen )
 {
   unsigned short port;
 
   //invalid length
   if( CodeLen != 7 )
+  {
+    debug_code_printf( "unknown" );
     return 0xFF;
+  }
   
+  debug_code_printf( "http port" );
+
   //get port number from from code
   port = Code5Bcd2Word( pCode, 2 );
 
   //save port for webserver
-  ConfigWebPort = port;
+  ConfigHttpPort = port;
   //schedule write to EEPROM
-  EepromNeedWrite |= EepromNeedWriteWebPort;
+  EepromNeedWrite |= EepromNeedWriteHttpPort;
 
   return 0x00;
 }
@@ -238,7 +274,12 @@ static inline unsigned char CodeSaveDefOut( unsigned char * pCode, unsigned char
 {
   //invalid length
   if( CodeLen != 2 )
+  {
+    debug_code_printf( "unknown" );
     return 0xFF;
+  }
+
+  debug_code_printf( "save default output" );
 
   //save default output state (atomically because only a single assignment)
   ConfigDefOut = OutputGetState( );
@@ -254,8 +295,13 @@ static inline unsigned char CodeSetDefOut( unsigned char * pCode, unsigned char
   unsigned char i, digit, defOut;
 
   //invalid length
-  if( CodeLen != 10 )
+  if( CodeLen != 10 ) 
+  {
+    debug_code_printf( "unknown" );
     return 0xFF;
+  }
+
+  debug_code_printf( "set default output" );
 
   //parse default output state into a single byte
   //8 times "0" or "1"
@@ -291,11 +337,17 @@ unsigned char CodeProc( unsigned char * pCode, unsigned char CodeLen )
 {
   //check green LED
   if( CodeLen == 0 )
+  {
+    debug_code_printf( "empty" );
     return 0x00;
+  }
 
   //not long enough for magic
   if( CodeLen < 2 )
+  {
+    debug_code_printf( "unknown" );
     return 0xFF;
+  }
 
   //branch according to magic
   switch( pCode[0] )
@@ -306,11 +358,13 @@ unsigned char CodeProc( unsigned char * pCode, unsigned char CodeLen )
     case 0x12: return CodeSetGw( pCode, CodeLen ); //set gateway IP address
     case 0x20: return CodeSetS8pPort( pCode, CodeLen ); //set port for S8P
     case 0x21: return CodeSetS8pKey( pCode, CodeLen ); //set symmetric key for S8P
-    case 0x30: return CodeSetWebPort( pCode, CodeLen ); //set port for webserver
+    case 0x30: return CodeSetHttpPort( pCode, CodeLen ); //set port for webserver
     case 0x40: return CodeSaveDefOut( pCode, CodeLen ); //save default output state
     case 0x41: return CodeSetDefOut( pCode, CodeLen ); //set default output state
   }
 
+  debug_code_printf( "unknown" );
+
   //unknown code
   return 0xFF;
 }
