@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3 date 2006-01-29
+ * version 0.4.0 date 2006-04-13
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -15,7 +15,7 @@
 #define EepromNeedWriteGw 0x08
 #define EepromNeedWriteS8pPort 0x10
 #define EepromNeedWriteS8pKey 0x20
-#define EepromNeedWriteWebPort 0x40
+#define EepromNeedWriteHttpPort 0x40
 #define EepromNeedWriteDefOut 0x80
 extern unsigned char EepromNeedWrite;
 
