@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3 date 2006-01-29
+ * version 0.4.0 date 2006-04-13
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -10,6 +10,7 @@
 #include "arp.h"
 #include "checksum.h"
 #include "config.h"
+#include "debug.h"
 #include "ethernet.h"
 #include "icmp.h"
 #include "ip.h"
@@ -35,7 +36,7 @@ struct IpBufferTable //table with buffers
   unsigned short PacketLength; //length of packet in buffer, 0 if no packet in this buffer
   unsigned char Ticks; //age of entry in 200ms steps
 } IpBufferTab[] =
-{ //put smaller buffers infont of larger buffers
+{ //put smaller buffers infront of larger buffers
   // - then short packets will use smaller buffers more often
   { IpBuffer0, sizeof( IpBuffer0 ), 0, 0 },
   { IpBuffer1, sizeof( IpBuffer1 ), 0, 0 },
@@ -122,6 +123,11 @@ void IpRecv( unsigned char * pData, unsigned short Length ) //(extern)
   if( Checksum( (unsigned char*)&pIpPack->IpHdr, sizeof( struct IpHeader ), 0x0000, 0x0000 ) != 0 )
     return;
 
+  debug_ip_printf( "recv src=%u.%u.%u.%u protocol=%u len=%u",
+                   pIpPack->IpHdr.Src[0], pIpPack->IpHdr.Src[1],
+                   pIpPack->IpHdr.Src[2], pIpPack->IpHdr.Src[3],
+                   pIpPack->IpHdr.Proto, Length );
+
   //branch according to protocol
   switch( pIpPack->IpHdr.Proto )
   {
@@ -156,6 +162,11 @@ void IpSend( unsigned char * pData, unsigned short Length ) //(extern)
   //(this saves us from always casting pData)
   pIpPack = (struct IpPacket *)pData;
 
+  debug_ip_printf( "send dest=%u.%u.%u.%u protocol=%u len=%u",
+                   pIpPack->IpHdr.Dest[0], pIpPack->IpHdr.Dest[1],
+                   pIpPack->IpHdr.Dest[2], pIpPack->IpHdr.Dest[3],
+                   pIpPack->IpHdr.Proto, Length );
+
   //fill in header values
   pIpPack->IpHdr.Ver_HdrLen = 0x45;
   pIpPack->IpHdr.Tos = 0x00;
@@ -201,6 +212,7 @@ void IpSend( unsigned char * pData, unsigned short Length ) //(extern)
       memcpy( IpBufferTab[i].pBuffer, pData, Length );
       IpBufferTab[i].PacketLength = Length;
       IpBufferTab[i].Ticks = 0;
+      debug_ip_printf( "queued" );
       break;
     }
   }
@@ -222,6 +234,11 @@ void IpGotMac( unsigned char Ip[4], unsigned char Mac[6] ) //(extern)
       //convert pointer to IP packet
       pIpPack = (struct IpPacket *)IpBufferTab[i].pBuffer;
 
+      debug_ip_printf( "send queued dest=%u.%u.%u.%u protocol=%u len=%u",
+                       pIpPack->IpHdr.Dest[0], pIpPack->IpHdr.Dest[1],
+                       pIpPack->IpHdr.Dest[2], pIpPack->IpHdr.Dest[3],
+                       pIpPack->IpHdr.Proto, IpBufferTab[i].PacketLength );
+
       //destination is in own subnet
       if( (pIpPack->IpHdr.Dest[0] & ConfigMask[0]) == (ConfigIp[0] & ConfigMask[0]) &&
           (pIpPack->IpHdr.Dest[1] & ConfigMask[1]) == (ConfigIp[1] & ConfigMask[1]) &&
