@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3 date 2006-01-29
+ * version 0.4.0 date 2006-04-13
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -177,30 +177,30 @@ void KeypadTick20( void ) //(extern)
   KeypadState &= ~Released;
 
   //output released and pressed keys in debug mode
-  if( Released & KEYPAD_MASK_0 ) debug_print( "key 0 released" );
-  if( Released & KEYPAD_MASK_1 ) debug_print( "key 1 released" );
-  if( Released & KEYPAD_MASK_2 ) debug_print( "key 2 released" );
-  if( Released & KEYPAD_MASK_3 ) debug_print( "key 3 released" );
-  if( Released & KEYPAD_MASK_4 ) debug_print( "key 4 released" );
-  if( Released & KEYPAD_MASK_5 ) debug_print( "key 5 released" );
-  if( Released & KEYPAD_MASK_6 ) debug_print( "key 6 released" );
-  if( Released & KEYPAD_MASK_7 ) debug_print( "key 7 released" );
-  if( Released & KEYPAD_MASK_8 ) debug_print( "key 8 released" );
-  if( Released & KEYPAD_MASK_9 ) debug_print( "key 9 released" );
-  if( Released & KEYPAD_MASK_STAR ) debug_print( "key * released" );
-  if( Released & KEYPAD_MASK_HASH ) debug_print( "key # released" );
-  if( Pressed & KEYPAD_MASK_0 ) debug_print( "key 0 pressed" );
-  if( Pressed & KEYPAD_MASK_1 ) debug_print( "key 1 pressed" );
-  if( Pressed & KEYPAD_MASK_2 ) debug_print( "key 2 pressed" );
-  if( Pressed & KEYPAD_MASK_3 ) debug_print( "key 3 pressed" );
-  if( Pressed & KEYPAD_MASK_4 ) debug_print( "key 4 pressed" );
-  if( Pressed & KEYPAD_MASK_5 ) debug_print( "key 5 pressed" );
-  if( Pressed & KEYPAD_MASK_6 ) debug_print( "key 6 pressed" );
-  if( Pressed & KEYPAD_MASK_7 ) debug_print( "key 7 pressed" );
-  if( Pressed & KEYPAD_MASK_8 ) debug_print( "key 8 pressed" );
-  if( Pressed & KEYPAD_MASK_9 ) debug_print( "key 9 pressed" );
-  if( Pressed & KEYPAD_MASK_STAR ) debug_print( "key * pressed" );
-  if( Pressed & KEYPAD_MASK_HASH ) debug_print( "key # pressed" );
+  if( Released & KEYPAD_MASK_0 ) debug_keys_printf( "0 up" );
+  if( Released & KEYPAD_MASK_1 ) debug_keys_printf( "1 up" );
+  if( Released & KEYPAD_MASK_2 ) debug_keys_printf( "2 up" );
+  if( Released & KEYPAD_MASK_3 ) debug_keys_printf( "3 up" );
+  if( Released & KEYPAD_MASK_4 ) debug_keys_printf( "4 up" );
+  if( Released & KEYPAD_MASK_5 ) debug_keys_printf( "5 up" );
+  if( Released & KEYPAD_MASK_6 ) debug_keys_printf( "6 up" );
+  if( Released & KEYPAD_MASK_7 ) debug_keys_printf( "7 up" );
+  if( Released & KEYPAD_MASK_8 ) debug_keys_printf( "8 up" );
+  if( Released & KEYPAD_MASK_9 ) debug_keys_printf( "9 up" );
+  if( Released & KEYPAD_MASK_STAR ) debug_keys_printf( "* up" );
+  if( Released & KEYPAD_MASK_HASH ) debug_keys_printf( "# up" );
+  if( Pressed & KEYPAD_MASK_0 ) debug_keys_printf( "0 down" );
+  if( Pressed & KEYPAD_MASK_1 ) debug_keys_printf( "1 down" );
+  if( Pressed & KEYPAD_MASK_2 ) debug_keys_printf( "2 down" );
+  if( Pressed & KEYPAD_MASK_3 ) debug_keys_printf( "3 down" );
+  if( Pressed & KEYPAD_MASK_4 ) debug_keys_printf( "4 down" );
+  if( Pressed & KEYPAD_MASK_5 ) debug_keys_printf( "5 down" );
+  if( Pressed & KEYPAD_MASK_6 ) debug_keys_printf( "6 down" );
+  if( Pressed & KEYPAD_MASK_7 ) debug_keys_printf( "7 down" );
+  if( Pressed & KEYPAD_MASK_8 ) debug_keys_printf( "8 down" );
+  if( Pressed & KEYPAD_MASK_9 ) debug_keys_printf( "9 down" );
+  if( Pressed & KEYPAD_MASK_STAR ) debug_keys_printf( "* down" );
+  if( Pressed & KEYPAD_MASK_HASH ) debug_keys_printf( "# down" );
 }
 
 //task function to do the work - call from main loop
