@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3 date 2006-01-29
+ * version 0.4.0 date 2006-04-13
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -25,15 +25,20 @@
 int main( void )
 {
   wdt_reset( );
+#ifdef DEBUG
+  wdt_disable( );
+#else
   wdt_enable( WDTO_60MS );
+#endif
   wdt_reset( );
 
   //initialize uart to be able to use stdio
   UartInit( );
 
-  debug_print( "" );
-  debug_print( "" );
-  debug_print( "init" );
+  debug_printf( "" );
+  debug_printf( "8BitAmEthernet" );
+
+  debug_init_printf( "init" );
 
   //initialize modules
   ArpInit( );
@@ -45,7 +50,7 @@ int main( void )
   TcpInit( );
   TimingInit( );
 
-  debug_print( "config" );
+  debug_init_printf( "config" );
 
   //get configuration from EEPROM
   EepromGetConfig( );
@@ -53,17 +58,22 @@ int main( void )
   //enable interrupts
   sei( );
 
-  debug_print( "start" );
+  debug_init_printf( "start" );
 
   //main loop
   while( 1 )
   {
     wdt_reset( );
     EepromTask( );
+    wdt_reset( );
     KeypadTask( );
+    wdt_reset( );
     RandomTask( );
+    wdt_reset( );
     RtlTask( );
+    wdt_reset( );
     S8pTask( );
+    wdt_reset( );
     TimingTask( );
   }
 
