@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.3 date 2006-01-29
+ * version 0.4.0 date 2006-04-13
  * Copyright 2005-2006 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -12,7 +12,7 @@
 #include "macros.h"
 #include "uart.h"
 
-#define BAUD_RATE 9600
+#define BAUD_RATE 38400
 
 //initialize
 void UartInit( void ) //(extern)
@@ -36,6 +36,6 @@ int UartPutchar( char c ) //(extern)
   //send character
   UDR0 = c;
 
-  return (0);
+  return 0;
 }
 
